@@ -108,7 +108,10 @@ class RegressionTask(PredictionTask):
 
 
 class NextItemPredictionTask(PredictionTask):
-    """Next-item prediction task.
+    """This block performs item prediction task for session and sequential-based models.
+    It requires a body containing a masking schema to use for training and target generation.
+    For the supported masking schemes, please refers to:
+    https://nvidia-merlin.github.io/Transformers4Rec/main/model_definition.html#sequence-masking
 
     Parameters
     ----------
@@ -194,11 +197,13 @@ class NextItemPredictionTask(PredictionTask):
                 # project input tensors to same dimension as item-id embeddings
                 task_block = MLPBlock([item_dim])
 
-        # Retrieve the masking if used in the model block
+        # Retrieve the masking from the input block
         self.masking = inputs.masking
-        if self.masking:
-            self.padding_idx = self.masking.padding_idx
-
+        if not self.masking:
+            raise ValueError(
+                "The input block should contain a masking schema for training and evaluation"
+            )
+        self.padding_idx = self.masking.padding_idx
         pre = NextItemPredictionPrepareBlock(
             target_dim=self.target_dim,
             weight_tying=self.weight_tying,
@@ -209,7 +214,7 @@ class NextItemPredictionTask(PredictionTask):
             body, input_size, device=device, inputs=inputs, task_block=task_block, pre=pre
         )
 
-    def forward(self, inputs: torch.Tensor, **kwargs):
+    def forward(self, inputs: torch.Tensor, ignore_masking=False, **kwargs):
         if isinstance(inputs, (tuple, list)):
             inputs = inputs[0]
         x = inputs.float()
@@ -217,17 +222,23 @@ class NextItemPredictionTask(PredictionTask):
         if self.task_block:
             x = self.task_block(x)  # type: ignore
 
-        # Retrieve labels either from masking or input module
-        if self.masking:
-            labels = self.masking.masked_targets
+        # Retrieve labels from masking
+        if not ignore_masking:
+            labels = self.masking.masked_targets  # type: ignore
+            trg_flat = labels.flatten()
+            non_pad_mask = trg_flat != self.padding_idx
+            labels_all = torch.masked_select(trg_flat, non_pad_mask)
+            # remove padded items, keep only masked positions
+            x = self.remove_pad_3d(x, non_pad_mask)
         else:
+            # keep only last non-padded position for the 'Prediction step'
             labels = self.embeddings.item_seq
-
-        # remove padded items
-        trg_flat = labels.flatten()
-        non_pad_mask = trg_flat != self.padding_idx
-        labels_all = torch.masked_select(trg_flat, non_pad_mask)
-        x = self.remove_pad_3d(x, non_pad_mask)
+            non_pad_mask = labels != self.padding_idx
+            last_item_sessions = non_pad_mask.sum(dim=1) - 1
+            rows_ids = torch.arange(labels.size(0), dtype=torch.long, device=labels.device)
+            labels_all = labels[rows_ids, last_item_sessions]
+            labels_all = labels_all.flatten()
+            x = x[rows_ids, last_item_sessions]
 
         # Compute predictions probs
         x = self.pre(x)  # type: ignore
